@@ -14,7 +14,7 @@
 
 static int
 is_a_console(int fd) {
-    long arg;
+    char arg;
 
     arg = 0;
     return (ioctl(fd, KDGKBTYPE, &arg) == 0 && arg == KB_101);
