@@ -1,7 +1,7 @@
 /*
  * setfont.c - Eugene Crosser & Andries Brouwer
  *
- * Version 0.91
+ * Version 0.92
  *
  * Loads the console font, and possibly the corresponding screen map(s).
  * We accept two kind of screen maps, one [-m] giving the correspondence
@@ -9,6 +9,8 @@
  * font positions, and the second [-u] giving the correspondence between
  * font positions and Unicode values.
  */
+#define VERSION "0.92"
+
 #include <stdio.h>
 #include <memory.h>
 #include <fcntl.h>
@@ -33,6 +35,8 @@ extern void activatemap(void);
 extern int getfd(void);
 extern char *malloc();
 
+int verbose = 0;
+
 /* search for the font in these directories (with trailing /) */
 char *fontdirpath[] = { "", DATADIR "/" FONTDIR "/", 0 };
 char *fontsuffixes[] = { "", ".psf", ".cp", ".fnt", ".psfu", 0 };
@@ -58,6 +62,8 @@ Options:
  -ou <filename>	Write current unicodemap to file before loading a new one.
  -m none	Suppress loading and activation of a mapping table.
  -u none	Suppress loading of a unicode map.
+ -v		Verbose.
+ -V		Print version.
 ", progname);
 	exit(1);
 }
@@ -77,7 +83,11 @@ main(int argc, char *argv[])
 	no_m = no_u = 0;
 
 	for (i = 1; i < argc; i++) {
-	    if (!strcmp(argv[i], "-o")) {
+	    if (!strcmp(argv[i], "-V")) {
+	        printf("setfont version %s\n", VERSION);
+	    } else if (!strcmp(argv[i], "-v")) {
+	        verbose = 1;
+	    } else if (!strcmp(argv[i], "-o")) {
 		if (++i == argc || ofil)
 		  usage();
 		ofil = argv[i];
@@ -163,7 +173,8 @@ do_loadfont(int fd, int unit, int fontsize, FILE *fpi) {
 	      exit(1);
 	  }
 
-	fprintf(stderr, "Loading 8x%d font from file %s\n", unit, pathname);
+	if (verbose)
+	  printf("Loading 8x%d font from file %s\n", unit, pathname);
 
 #ifdef PIO_FONTX
 	{
@@ -229,7 +240,8 @@ do_loadtable(int fd, int tailsz, int fontsize, FILE *fpi) {
 	      perror("PIO_UNIMAPCLR");
 	    exit(1);
 	}
-	fprintf(stderr,"Loading Unicode mapping table...\n");
+	if (verbose)
+	  printf("Loading Unicode mapping table...\n");
 	ud.entry_ct = ct;
 	ud.entries = up;
 	if(ioctl(fd, PIO_UNIMAP, &ud)) {
@@ -403,7 +415,8 @@ saveoldfont(int fd, char *ofil) {
 	      perror("Cannot write font file");
 	      exit(1);
 	  }
-	printf("Saved 8x%d font file on %s\n", unit, ofil);
+	if (verbose)
+	  printf("Saved 8x%d font file on %s\n", unit, ofil);
     }
     fclose(fpo);
 }
@@ -417,3 +430,8 @@ void
 activatemap(void) {
     printf("\033(K");
 }
+
+void
+disactivatemap(void) {
+    printf("\033(B");
+}
